<?
//OpenGraph attributes
PageLayout::addHeadElement("meta", ['property' => "og:site_name", 'content' => _("Stud.IP Plugin-Marktplatz")]);
PageLayout::addHeadElement("meta", ['property' => "og:type", 'content' => "article"]);
PageLayout::addHeadElement("meta", ['property' => "og:title", 'content' => $marketplugin['name']]);
PageLayout::addHeadElement("meta", ['property' => "og:description", 'content' => $marketplugin['short_description']]);
$image = $marketplugin->images->first();
if ($image) {
    PageLayout::addHeadElement("meta", ['property' => "og:image", 'content' => $image->getURL(true)]);
}
?>

<? if (!$marketplugin['publiclyvisible']) : ?>
    <?= MessageBox::info(_("Dieses Plugin ist nicht öffentlich."))->hideClose() ?>
<? endif ?>

<h1><?= htmlReady($marketplugin['name']) ?></h1>
<div>
    <?= htmlReady($marketplugin['short_description']) ?>
</div>
<?if ($marketplugin['description']) : ?>
    <div>
        <br>
        <?= formatReady($marketplugin['description']) ?>
    </div>
<? endif ?>
<? if (count($marketplugin->images) > 0 || $marketplugin->isWritable()) : ?>
<h2><?= _("Galerie") ?></h2>

<ol id="pluginmarket_galery_view" class="pluginmarket_galery">
    <? foreach ($marketplugin->images as $image) : ?>
    <div class="image">
        <a href="<?= htmlReady($image->getURL()) ?>" data-lightbox="plugin_gallery">
            <img src="<?= htmlReady($image->getURL()) ?>">
        </a>
    </div>
    <? endforeach ?>
    <? if ($marketplugin->isWritable()) : ?>
    <div>
        <a href="<?= PluginEngine::getLink($plugin, [], "myplugins/edit_images/". $marketplugin->getId())  ?>" data-dialog title="<?= _("Galerie bearbeiten / neue Bilder hinzufügen") ?>">
            <?= Icon::create('add')->asImg(20) ?>
        </a>
    </div>
    <? endif ?>
</ol>
<? endif ?>

<h2><?= _("In Benutzung bei") ?></h2>
<ul class="plugin-usages">
    <? foreach ($marketplugin['uses'] as $use): ?>
        <li>
            <a href="<?= PluginEngine::getLink($plugin, ['search' => $use->name], "presenting/all") ?>">
                <?= htmlReady($use->name) ?>
            </a>
            <? if ($use->plugin->isWritable(User::findCurrent()->id)): ?>
            (<?= ObjectdisplayHelper::link($use->user) ?>)
            <? endif; ?>
            <? if ($use->isEditable()): ?>
                <a href="<?= PluginEngine::getLink($plugin, [], "presenting/delete_usage/" . $use->id) ?>">
                    <?= Icon::create('trash')->asImg(20) ?>
                </a>
            <? endif; ?>
        </li>
    <? endforeach; ?>
</ul>

<? if ($marketplugin['url']) : ?>
    <h2><?= _('Projekthomepage') ?></h2>
    <div><?= formatLinks($marketplugin['url']) ?></div>
<? endif ?>

<? $tags = $marketplugin->getTags() ?>
<? if (count($tags)) : ?>
    <h2><?= _('Schlagworte') ?></h2>
    <div>
        <? foreach ($tags as $key => $tag) : ?>
            <?= $key > 0 ? "," : "" ?>
            <a href="<?= URLHelper::getLink('plugins.php/pluginmarket/presenting/all', ['tag' => $tag]) ?>">
                <?= Icon::create('tag')->asImg(20, ['class' => 'text-bottom']) ?>
                <?= htmlReady(ucwords($tag)) ?>
            </a>
        <? endforeach ?>
    </div>
<? endif ?>

<h2><?= _('Zum Autor') ?></h2>
<ul class="clean plugins_authors">
    <li>
        <? $author = User::find($marketplugin['user_id']) ?>
        <div>
            <? if ($author) : ?>
            <a href="<?= URLHelper::getLink('dispatch.php/profile', ['username' => $author['username']]) ?>" style="text-align: center; display: inline-block; vertical-align: top;">
                <?= Avatar::getAvatar($marketplugin['user_id'])->getImageTag(Avatar::MEDIUM, ['style' => "display: block;"]) ?>
                <?= htmlReady($author->getFullName()) ?>
            </a>
            <? else : ?>
                <?= _('unbekannt') ?>
            <? endif ?>
        </div>
    </li>
    <? foreach ($marketplugin->more_users as $user) : ?>
        <li>
            <div>
                <a href="<?= URLHelper::getLink("dispatch.php/profile", ['username' => $user['username']]) ?>" style="text-align: center; display: inline-block; vertical-align: top;">
                    <?= Avatar::getAvatar($user->getId())->getImageTag(Avatar::MEDIUM, ['style' => "display: block;"]) ?>
                    <?= htmlReady($user->getFullName()) ?>
                </a>
            </div>
        </li>
    <? endforeach ?>
</ul>

<h2><?= _('Releases') ?></h2>
<table class="default">
    <thead>
        <tr>
            <th><?= _('Version') ?></th>
            <th><?= _('Min. Stud.IP Version') ?></th>
            <th><?= _('Max. Stud.IP Version') ?></th>
            <th><?= _('Hochgeladen am') ?></th>
            <th><?= _('MD5-Prüfsumme') ?></th>
            <th><?= _('Downloads') ?></th>
            <th></th>
        </tr>
    </thead>
    <tbody>
    <? foreach ($marketplugin->releases->orderBy('version DESC') as $release) : ?>
        <tr>
            <td>
                <a href="<?= PluginEngine::getLink($plugin, [], 'presenting/download/' . $release->getId()) ?>" title="<?= _("Dieses Release runterladen") ?>">
                    <?= Icon::create('download')->asImg(20, ['class' => 'text-bottom']) ?>
                    <?= htmlReady($release['version']) ?>
                </a>
            </td>
            <td><?= $release['studip_min_version'] ? htmlReady($release['studip_min_version']) : " - " ?></td>
            <td><?= $release['studip_max_version'] ? htmlReady($release['studip_max_version']) : " - " ?></td>
            <td><?= strftime("%x %R", $release['last_upload_time']) ?></td>
            <td><?= htmlReady($release->getChecksum()) ?></td>
            <td><?= htmlReady($release['downloads']) ?></td>
            <td class="actions">
                <? if ($marketplugin->isWritable()) : ?>
                    <a href="<?= PluginEngine::getLink($plugin, [], "myplugins/edit_release/" . $release->getId()) ?>" data-dialog>
                        <?= Icon::create('edit')->asImg(20, ['class' => "text-bottom"]) ?>
                    </a>
                    <a href="<?= PluginEngine::getLink($plugin, [], "presenting/delete_release/" . $release->getId())  ?>">
                        <?= Icon::create('trash')->asImg(20, ['class' => 'text-bottom', 'data-confirm' => _('Pluginrelease wirklich unwiderrufbar löschen?')]) ?>
                    </a>
                <? endif ?>
                <? if ($GLOBALS['perm']->have_perm("autor")) : ?>
                    <a href="<?= PluginEngine::getLink($plugin, [], "presenting/follow_release/" . $release->getId()) ?>" title="<?= _('Für automatische Updates registrieren.') ?>" data-dialog>
                        <?= Icon::create('rss')->asImg(20, ['class' => 'text-bottom']) ?>
                    </a>
                <? endif ?>
            </td>
        </tr>
    <? endforeach ?>
    </tbody>
    <? if ($marketplugin->isWritable()) : ?>
        <tfoot>
        <tr>
            <td colspan="7">
                <a href="<?= PluginEngine::getLink($plugin, [], 'myplugins/add_release/' . $marketplugin->getId()) ?>" data-dialog>
                    <?= Icon::create('add')->asImg(20, ['class' => 'text-bottom']) ?>
                </a>
            </td>
        </tr>
        </tfoot>
    <? endif ?>
</table>



<h2><?= _("Bewertungen") ?></h2>
<div>
    <div style="text-align: center;">
        <? if ($marketplugin['rating'] === null) : ?>
            <? if (!$marketplugin->isWritable()) : ?>
                <a style="opacity: 0.3;" title="<?= $GLOBALS['perm']->have_perm("autor") ? _("Geben Sie die erste Bewertung ab.") : _("Noch keine bewertung abgegeben.") ?>" <?= ($GLOBALS['perm']->have_perm("autor") && !$marketplugin->isWritable()) ? 'href="' . $controller->url_for('presenting/review/' . $marketplugin->getId()) . '" data-dialog' : "" ?>>
                <? $icon_prefix = "blue_" ?>
            <? endif ?>
                <?= Icon::create($plugin->getPluginURL()."/assets/".($icon_prefix ?? '')."star.svg")->asImg("50px") ?>
                <?= Icon::create($plugin->getPluginURL()."/assets/".($icon_prefix ?? '')."star.svg")->asImg("50px") ?>
                <?= Icon::create($plugin->getPluginURL()."/assets/".($icon_prefix ?? '')."star.svg")->asImg("50px") ?>
                <?= Icon::create($plugin->getPluginURL()."/assets/".($icon_prefix ?? '')."star.svg")->asImg("50px") ?>
                <?= Icon::create($plugin->getPluginURL()."/assets/".($icon_prefix ?? '')."star.svg")->asImg("50px") ?>
            <? if (!$marketplugin->isWritable()) : ?>
                </a>
            <? endif ?>
        <? else : ?>
            <? if (!$marketplugin->isWritable()) : ?>
                <a <?= ($GLOBALS['perm']->have_perm("autor") && !$marketplugin->isWritable()) ? 'href="' . $controller->url_for('presenting/review/' . $marketplugin->getId()) . '" data-dialog' : "" ?> title="<?= sprintf(_("%s von 5 Sternen"), round($marketplugin['rating'] / 2, 1)) ?>">
                <? $icon_prefix = "blue_" ?>
            <? endif ?>
                <? $marketplugin['rating'] = round($marketplugin['rating'], 1) / 2 ?>
                <? $v = $marketplugin['rating'] >= 0.75 ? 3 : ($marketplugin['rating'] >= 0.25 ? 2 : "") ?>
                <?= Icon::create($plugin->getPluginURL()."/assets/".($icon_prefix ?? '')."star$v.svg")->asImg("50px") ?>

                <? $v = $marketplugin['rating'] >= 1.75 ? 3 : ($marketplugin['rating'] >= 1.25 ? 2 : "") ?>
                <?= Icon::create($plugin->getPluginURL()."/assets/".($icon_prefix ?? '')."star$v.svg")->asImg("50px") ?>
                <? $v = $marketplugin['rating'] >= 2.75 ? 3 : ($marketplugin['rating'] >= 2.25 ? 2 : "") ?>
                <?= Icon::create($plugin->getPluginURL()."/assets/".($icon_prefix ?? '')."star$v.svg")->asImg("50px") ?>
                <? $v = $marketplugin['rating'] >= 3.75 ? 3 : ($marketplugin['rating'] >= 3.25 ? 2 : "") ?>
                <?= Icon::create($plugin->getPluginURL()."/assets/".($icon_prefix ?? '')."star$v.svg")->asImg("50px") ?>
                <? $v = $marketplugin['rating'] >= 4.75 ? 3 : ($marketplugin['rating'] >= 4.25 ? 2 : "") ?>
                <?= Icon::create($plugin->getPluginURL()."/assets/".($icon_prefix ?? '')."star$v.svg")->asImg("50px") ?>
            <? if (!$marketplugin->isWritable()) : ?>
                </a>
            <? endif ?>
        <? endif ?>
    </div>

    <ol style="list-style-type: none; padding: none; margin: none;">
    <? foreach ($marketplugin->reviews as $review) : ?>
        <? if ($review['review']) : ?>
        <li style="padding: none; margin: none;">
            <blockquote class="quote">
                <div class="author">
                    <div style="float: right;"><?= date("j.n.Y", $review['chdate']) ?></div>
                    <?= sprintf(_("Rezension von %s"), $GLOBALS['user']->id !== "nobody"
                        ? '<a style="color: white;" href="'.URLHelper::getLink("dispatch.php/profile", ['username' => get_username($review['user_id'])]).'">'.Icon::create("link-intern", "info_alt")->asImg(['class' => "text-bottom"])." ".htmlReady(get_fullname($review['user_id'])).'</a>'
                        : htmlReady(get_fullname($review['user_id'])) ) ?>:
                </div>
                <div>
                    <? $v = $review['rating'] >= 1 ? 3 : "" ?>
                    <?= Icon::create($plugin->getPluginURL()."/assets/star$v.svg")->asImg("20px") ?>
                    <? $v = $review['rating'] >= 2 ? 3 : "" ?>
                    <?= Icon::create($plugin->getPluginURL()."/assets/star$v.svg")->asImg("20px") ?>
                    <? $v = $review['rating'] >= 3 ? 3 : "" ?>
                    <?= Icon::create($plugin->getPluginURL()."/assets/star$v.svg")->asImg("20px") ?>
                    <? $v = $review['rating'] >= 4 ? 3 : "" ?>
                    <?= Icon::create($plugin->getPluginURL()."/assets/star$v.svg")->asImg("20px") ?>
                    <? $v = $review['rating'] >= 5 ? 3 : "" ?>
                    <?= Icon::create($plugin->getPluginURL()."/assets/star$v.svg")->asImg("20px") ?>
                </div>
                <?= htmlReady($review['review']) ?>
            </blockquote>
        </li>
        <? endif ?>
    <? endforeach ?>
    </ol>

</div>

<div style="text-align: center">
<? if ($marketplugin->isWritable()) : ?>
    <?= \Studip\LinkButton::create(_("Plugin löschen"), PluginEngine::getURL($plugin, [], 'myplugins/delete/' . $marketplugin->getId()), ['data-dialog' => '']) ?>
    <?= \Studip\LinkButton::create(_("Bearbeiten"), PluginEngine::getURL($plugin, [], "myplugins/edit/" . $marketplugin->getId()), ['data-dialog' => '']) ?>
    <?= \Studip\LinkButton::create(_("Release hinzufügen"), PluginEngine::getURL($plugin, [], "myplugins/add_release/" . $marketplugin->getId()), ['data-dialog' => '']) ?>
<? endif ?>
<? if (!$marketplugin->isWritable()) : ?>
    <?= \Studip\LinkButton::create(_("Bewertung schreiben"), $controller->url_for('presenting/review/' . $marketplugin->getId()), ['data-dialog' => '']) ?>
<? endif ?>
<? if ($marketplugin['user_id'] !== $GLOBALS['user']->id) : ?>
    <?= \Studip\LinkButton::create(_("Plugin abonnieren"), PluginEngine::getURL($plugin, [], "presenting/register_for_pluginnews/" . $marketplugin->getId()), ['title' => _("Neuigkeiten des Plugins per Nachricht bekommen."), 'data-dialog' => "1"]) ?>
<? endif ?>
</div>
